package ch.std.jumpstart.rest;

import org.modelmapper.ModelMapper;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.data.web.PageableDefault;
import org.springframework.data.web.SortDefault;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import ch.std.jumpstart.dto.CityDTO;
import ch.std.jumpstart.jpa.City;
import ch.std.jumpstart.service.CityService;

@RestController
public class CityJpaController {

	private CityService cityService;	

	private ModelMapper modelMapper;

	public CityJpaController(CityService cityService, ModelMapper modelMapper) { // autowired
		this.cityService = cityService;
		this.modelMapper = modelMapper;
	}

	@GetMapping("/rest/citiesjpa")
	public CityDTO[] getCities(@RequestParam(value = "value", defaultValue="") String value,
			@PageableDefault(page = 0, size = 10) @SortDefault.SortDefaults({
				@SortDefault(sort="name", direction=Sort.Direction.ASC)
			}) Pageable pageable) {
		Page<City> cities = this.cityService.find(value, pageable);
		return cities.stream().map(city -> convertToDTO(city)).toArray(CityDTO[]::new);
	}

	private CityDTO convertToDTO(City city) {
		return this.modelMapper.map(city, CityDTO.class);
	}
}
